"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.batchAccountsClose = void 0;
const generated_1 = require("../generated");
const pda_1 = require("../pda");
/**
 * Closes Batch and the corresponding Proposal accounts for proposals in terminal states:
 * `Executed`, `Rejected`, or `Cancelled` or stale proposals that aren't Approved.
 *
 * This instruction is only allowed to be executed when all `VaultBatchTransaction` accounts
 * in the `batch` are already closed: `batch.size == 0`.
 */
function batchAccountsClose({ multisigPda, rentCollector, batchIndex, programId = generated_1.PROGRAM_ID, }) {
    const [proposalPda] = (0, pda_1.getProposalPda)({
        multisigPda,
        transactionIndex: batchIndex,
        programId,
    });
    const [batchPda] = (0, pda_1.getTransactionPda)({
        multisigPda,
        index: batchIndex,
        programId,
    });
    return (0, generated_1.createBatchAccountsCloseInstruction)({
        multisig: multisigPda,
        rentCollector,
        proposal: proposalPda,
        batch: batchPda,
    }, programId);
}
exports.batchAccountsClose = batchAccountsClose;
//# sourceMappingURL=batchAccountsClose.js.map