"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.batchAddTransaction = void 0;
const generated_1 = require("../generated");
const pda_1 = require("../pda");
const utils_1 = require("../utils");
function batchAddTransaction({ vaultIndex, multisigPda, member, rentPayer, batchIndex, transactionIndex, ephemeralSigners, transactionMessage, addressLookupTableAccounts, programId = generated_1.PROGRAM_ID, }) {
    const [proposalPda] = (0, pda_1.getProposalPda)({
        multisigPda,
        transactionIndex: batchIndex,
        programId,
    });
    const [batchPda] = (0, pda_1.getTransactionPda)({
        multisigPda,
        index: batchIndex,
        programId,
    });
    const [batchTransactionPda] = (0, pda_1.getBatchTransactionPda)({
        multisigPda,
        batchIndex,
        transactionIndex,
        programId,
    });
    const [vaultPda] = (0, pda_1.getVaultPda)({
        multisigPda,
        index: vaultIndex,
        programId,
    });
    const transactionMessageBytes = (0, utils_1.transactionMessageToMultisigTransactionMessageBytes)({
        message: transactionMessage,
        addressLookupTableAccounts,
        vaultPda,
    });
    return (0, generated_1.createBatchAddTransactionInstruction)({
        multisig: multisigPda,
        member,
        proposal: proposalPda,
        rentPayer: rentPayer !== null && rentPayer !== void 0 ? rentPayer : member,
        batch: batchPda,
        transaction: batchTransactionPda,
    }, {
        args: {
            ephemeralSigners,
            transactionMessage: transactionMessageBytes,
        },
    }, programId);
}
exports.batchAddTransaction = batchAddTransaction;
//# sourceMappingURL=batchAddTransaction.js.map