"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.batchExecuteTransaction = void 0;
const generated_1 = require("../generated");
const pda_1 = require("../pda");
const utils_1 = require("../utils");
function batchExecuteTransaction({ connection, multisigPda, member, batchIndex, transactionIndex, programId = generated_1.PROGRAM_ID, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const [proposalPda] = (0, pda_1.getProposalPda)({
            multisigPda,
            transactionIndex: batchIndex,
            programId,
        });
        const [batchPda] = (0, pda_1.getTransactionPda)({
            multisigPda,
            index: batchIndex,
            programId,
        });
        const [batchTransactionPda] = (0, pda_1.getBatchTransactionPda)({
            multisigPda,
            batchIndex,
            transactionIndex,
            programId,
        });
        const batchAccount = yield generated_1.Batch.fromAccountAddress(connection, batchPda);
        const [vaultPda] = (0, pda_1.getVaultPda)({
            multisigPda,
            index: batchAccount.vaultIndex,
            programId,
        });
        const batchTransactionAccount = yield generated_1.VaultBatchTransaction.fromAccountAddress(connection, batchTransactionPda);
        const { accountMetas, lookupTableAccounts } = yield (0, utils_1.accountsForTransactionExecute)({
            connection,
            message: batchTransactionAccount.message,
            ephemeralSignerBumps: [...batchTransactionAccount.ephemeralSignerBumps],
            vaultPda,
            transactionPda: batchPda,
        });
        return {
            instruction: (0, generated_1.createBatchExecuteTransactionInstruction)({
                multisig: multisigPda,
                member,
                proposal: proposalPda,
                batch: batchPda,
                transaction: batchTransactionPda,
                anchorRemainingAccounts: accountMetas,
            }, programId),
            lookupTableAccounts,
        };
    });
}
exports.batchExecuteTransaction = batchExecuteTransaction;
//# sourceMappingURL=batchExecuteTransaction.js.map