"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.configTransactionExecute = void 0;
const web3_js_1 = require("@solana/web3.js");
const generated_1 = require("../generated");
const pda_1 = require("../pda");
function configTransactionExecute({ multisigPda, transactionIndex, member, rentPayer, spendingLimits, programId = generated_1.PROGRAM_ID, }) {
    const [proposalPda] = (0, pda_1.getProposalPda)({
        multisigPda,
        transactionIndex,
        programId,
    });
    const [transactionPda] = (0, pda_1.getTransactionPda)({
        multisigPda,
        index: transactionIndex,
        programId,
    });
    return (0, generated_1.createConfigTransactionExecuteInstruction)({
        multisig: multisigPda,
        member,
        proposal: proposalPda,
        transaction: transactionPda,
        rentPayer,
        systemProgram: web3_js_1.SystemProgram.programId,
        anchorRemainingAccounts: spendingLimits === null || spendingLimits === void 0 ? void 0 : spendingLimits.map((spendingLimit) => ({
            pubkey: spendingLimit,
            isWritable: true,
            isSigner: false,
        })),
    }, programId);
}
exports.configTransactionExecute = configTransactionExecute;
//# sourceMappingURL=configTransactionExecute.js.map