"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.vaultBatchTransactionAccountClose = void 0;
const generated_1 = require("../generated");
const pda_1 = require("../pda");
/**
 * Closes a VaultBatchTransaction belonging to the Batch and Proposal defined by `batchIndex`.
 * VaultBatchTransaction can be closed if either:
 * - it's marked as executed within the batch;
 * - the proposal is in a terminal state: `Executed`, `Rejected`, or `Cancelled`.
 * - the proposal is stale and not `Approved`.
 */
function vaultBatchTransactionAccountClose({ multisigPda, rentCollector, batchIndex, transactionIndex, programId = generated_1.PROGRAM_ID, }) {
    const [proposalPda] = (0, pda_1.getProposalPda)({
        multisigPda,
        transactionIndex: batchIndex,
        programId,
    });
    const [batchPda] = (0, pda_1.getTransactionPda)({
        multisigPda,
        index: batchIndex,
        programId,
    });
    const [batchTransactionPda] = (0, pda_1.getBatchTransactionPda)({
        multisigPda,
        batchIndex,
        transactionIndex,
        programId,
    });
    return (0, generated_1.createVaultBatchTransactionAccountCloseInstruction)({
        multisig: multisigPda,
        rentCollector,
        proposal: proposalPda,
        batch: batchPda,
        transaction: batchTransactionPda,
    }, programId);
}
exports.vaultBatchTransactionAccountClose = vaultBatchTransactionAccountClose;
//# sourceMappingURL=vaultBatchTransactionAccountClose.js.map