"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.vaultTransactionCreate = void 0;
const generated_1 = require("../generated");
const pda_1 = require("../pda");
const utils_1 = require("../utils");
function vaultTransactionCreate({ multisigPda, transactionIndex, creator, rentPayer, vaultIndex, ephemeralSigners, transactionMessage, addressLookupTableAccounts, memo, programId = generated_1.PROGRAM_ID, }) {
    const [vaultPda] = (0, pda_1.getVaultPda)({
        multisigPda,
        index: vaultIndex,
        programId,
    });
    const [transactionPda] = (0, pda_1.getTransactionPda)({
        multisigPda,
        index: transactionIndex,
        programId,
    });
    const transactionMessageBytes = (0, utils_1.transactionMessageToMultisigTransactionMessageBytes)({
        message: transactionMessage,
        addressLookupTableAccounts,
        vaultPda,
    });
    return (0, generated_1.createVaultTransactionCreateInstruction)({
        multisig: multisigPda,
        transaction: transactionPda,
        creator,
        rentPayer: rentPayer !== null && rentPayer !== void 0 ? rentPayer : creator,
    }, {
        args: {
            vaultIndex,
            ephemeralSigners,
            transactionMessage: transactionMessageBytes,
            memo: memo !== null && memo !== void 0 ? memo : null,
        },
    }, programId);
}
exports.vaultTransactionCreate = vaultTransactionCreate;
//# sourceMappingURL=vaultTransactionCreate.js.map