"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.vaultTransactionExecute = void 0;
const pda_1 = require("../pda");
const generated_1 = require("../generated");
const utils_1 = require("../utils");
function vaultTransactionExecute({ connection, multisigPda, transactionIndex, member, programId = generated_1.PROGRAM_ID, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const [proposalPda] = (0, pda_1.getProposalPda)({
            multisigPda,
            transactionIndex,
            programId,
        });
        const [transactionPda] = (0, pda_1.getTransactionPda)({
            multisigPda,
            index: transactionIndex,
            programId,
        });
        const transactionAccount = yield generated_1.VaultTransaction.fromAccountAddress(connection, transactionPda);
        const [vaultPda] = (0, pda_1.getVaultPda)({
            multisigPda,
            index: transactionAccount.vaultIndex,
            programId,
        });
        const { accountMetas, lookupTableAccounts } = yield (0, utils_1.accountsForTransactionExecute)({
            connection,
            message: transactionAccount.message,
            ephemeralSignerBumps: [...transactionAccount.ephemeralSignerBumps],
            vaultPda,
            transactionPda,
            programId,
        });
        return {
            instruction: (0, generated_1.createVaultTransactionExecuteInstruction)({
                multisig: multisigPda,
                member,
                proposal: proposalPda,
                transaction: transactionPda,
                anchorRemainingAccounts: accountMetas,
            }, programId),
            lookupTableAccounts,
        };
    });
}
exports.vaultTransactionExecute = vaultTransactionExecute;
//# sourceMappingURL=vaultTransactionExecute.js.map