"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSpendingLimitPda = exports.getBatchTransactionPda = exports.getProposalPda = exports.getTransactionPda = exports.getEphemeralSignerPda = exports.getVaultPda = exports.getMultisigPda = exports.getProgramConfigPda = void 0;
const web3_js_1 = require("@solana/web3.js");
const generated_1 = require("./generated");
const utils_1 = require("./utils");
const invariant_1 = __importDefault(require("invariant"));
const SEED_PREFIX = (0, utils_1.toUtfBytes)("multisig");
const SEED_PROGRAM_CONFIG = (0, utils_1.toUtfBytes)("program_config");
const SEED_MULTISIG = (0, utils_1.toUtfBytes)("multisig");
const SEED_VAULT = (0, utils_1.toUtfBytes)("vault");
const SEED_TRANSACTION = (0, utils_1.toUtfBytes)("transaction");
const SEED_PROPOSAL = (0, utils_1.toUtfBytes)("proposal");
const SEED_BATCH_TRANSACTION = (0, utils_1.toUtfBytes)("batch_transaction");
const SEED_EPHEMERAL_SIGNER = (0, utils_1.toUtfBytes)("ephemeral_signer");
const SEED_SPENDING_LIMIT = (0, utils_1.toUtfBytes)("spending_limit");
function getProgramConfigPda({ programId = generated_1.PROGRAM_ID, }) {
    return web3_js_1.PublicKey.findProgramAddressSync([SEED_PREFIX, SEED_PROGRAM_CONFIG], programId);
}
exports.getProgramConfigPda = getProgramConfigPda;
function getMultisigPda({ createKey, programId = generated_1.PROGRAM_ID, }) {
    return web3_js_1.PublicKey.findProgramAddressSync([SEED_PREFIX, SEED_MULTISIG, createKey.toBytes()], programId);
}
exports.getMultisigPda = getMultisigPda;
function getVaultPda({ multisigPda, 
/** Authority index. */
index, programId = generated_1.PROGRAM_ID, }) {
    (0, invariant_1.default)(index >= 0 && index < 256, "Invalid vault index");
    return web3_js_1.PublicKey.findProgramAddressSync([SEED_PREFIX, multisigPda.toBytes(), SEED_VAULT, (0, utils_1.toU8Bytes)(index)], programId);
}
exports.getVaultPda = getVaultPda;
function getEphemeralSignerPda({ transactionPda, ephemeralSignerIndex, programId = generated_1.PROGRAM_ID, }) {
    return web3_js_1.PublicKey.findProgramAddressSync([
        SEED_PREFIX,
        transactionPda.toBytes(),
        SEED_EPHEMERAL_SIGNER,
        (0, utils_1.toU8Bytes)(ephemeralSignerIndex),
    ], programId);
}
exports.getEphemeralSignerPda = getEphemeralSignerPda;
function getTransactionPda({ multisigPda, index, programId = generated_1.PROGRAM_ID, }) {
    return web3_js_1.PublicKey.findProgramAddressSync([SEED_PREFIX, multisigPda.toBytes(), SEED_TRANSACTION, (0, utils_1.toU64Bytes)(index)], programId);
}
exports.getTransactionPda = getTransactionPda;
function getProposalPda({ multisigPda, transactionIndex, programId = generated_1.PROGRAM_ID, }) {
    return web3_js_1.PublicKey.findProgramAddressSync([
        SEED_PREFIX,
        multisigPda.toBytes(),
        SEED_TRANSACTION,
        (0, utils_1.toU64Bytes)(transactionIndex),
        SEED_PROPOSAL,
    ], programId);
}
exports.getProposalPda = getProposalPda;
function getBatchTransactionPda({ multisigPda, batchIndex, transactionIndex, programId = generated_1.PROGRAM_ID, }) {
    return web3_js_1.PublicKey.findProgramAddressSync([
        SEED_PREFIX,
        multisigPda.toBytes(),
        SEED_TRANSACTION,
        (0, utils_1.toU64Bytes)(batchIndex),
        SEED_BATCH_TRANSACTION,
        (0, utils_1.toU32Bytes)(transactionIndex),
    ], programId);
}
exports.getBatchTransactionPda = getBatchTransactionPda;
function getSpendingLimitPda({ multisigPda, createKey, programId = generated_1.PROGRAM_ID, }) {
    return web3_js_1.PublicKey.findProgramAddressSync([
        SEED_PREFIX,
        multisigPda.toBytes(),
        SEED_SPENDING_LIMIT,
        createKey.toBytes(),
    ], programId);
}
exports.getSpendingLimitPda = getSpendingLimitPda;
//# sourceMappingURL=pda.js.map