"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.accountsForTransactionExecute = exports.transactionMessageToMultisigTransactionMessageBytes = exports.isSignerIndex = exports.isStaticWritableIndex = exports.getAvailableMemoSize = exports.toBigInt = exports.toU64Bytes = exports.toU32Bytes = exports.toU8Bytes = exports.toUtfBytes = void 0;
const beet_1 = require("@metaplex-foundation/beet");
const buffer_1 = require("buffer");
const types_1 = require("./types");
const pda_1 = require("./pda");
const invariant_1 = __importDefault(require("invariant"));
const compileToWrappedMessageV0_1 = require("./utils/compileToWrappedMessageV0");
function toUtfBytes(str) {
    return new TextEncoder().encode(str);
}
exports.toUtfBytes = toUtfBytes;
function toU8Bytes(num) {
    const bytes = buffer_1.Buffer.alloc(1);
    beet_1.u8.write(bytes, 0, num);
    return bytes;
}
exports.toU8Bytes = toU8Bytes;
function toU32Bytes(num) {
    const bytes = buffer_1.Buffer.alloc(4);
    beet_1.u32.write(bytes, 0, num);
    return bytes;
}
exports.toU32Bytes = toU32Bytes;
function toU64Bytes(num) {
    const bytes = buffer_1.Buffer.alloc(8);
    beet_1.u64.write(bytes, 0, num);
    return bytes;
}
exports.toU64Bytes = toU64Bytes;
function toBigInt(number) {
    return BigInt(number.toString());
}
exports.toBigInt = toBigInt;
const MAX_TX_SIZE_BYTES = 1232;
const STRING_LEN_SIZE = 4;
function getAvailableMemoSize(txWithoutMemo) {
    const txSize = txWithoutMemo.serialize().length;
    return (MAX_TX_SIZE_BYTES -
        txSize -
        STRING_LEN_SIZE -
        // Sometimes long memo can trigger switching from 1 to 2 bytes length encoding in Compact-u16,
        // so we reserve 1 extra byte to make sure.
        1);
}
exports.getAvailableMemoSize = getAvailableMemoSize;
function isStaticWritableIndex(message, index) {
    const numAccountKeys = message.accountKeys.length;
    const { numSigners, numWritableSigners, numWritableNonSigners } = message;
    if (index >= numAccountKeys) {
        // `index` is not a part of static `accountKeys`.
        return false;
    }
    if (index < numWritableSigners) {
        // `index` is within the range of writable signer keys.
        return true;
    }
    if (index >= numSigners) {
        // `index` is within the range of non-signer keys.
        const indexIntoNonSigners = index - numSigners;
        // Whether `index` is within the range of writable non-signer keys.
        return indexIntoNonSigners < numWritableNonSigners;
    }
    return false;
}
exports.isStaticWritableIndex = isStaticWritableIndex;
function isSignerIndex(message, index) {
    return index < message.numSigners;
}
exports.isSignerIndex = isSignerIndex;
/** We use custom serialization for `transaction_message` that ensures as small byte size as possible. */
function transactionMessageToMultisigTransactionMessageBytes({ message, addressLookupTableAccounts, vaultPda, }) {
    // // Make sure authority is marked as non-signer in all instructions,
    // // otherwise the message will be serialized in incorrect format.
    // message.instructions.forEach((instruction) => {
    //   instruction.keys.forEach((key) => {
    //     if (key.pubkey.equals(vaultPda)) {
    //       key.isSigner = false;
    //     }
    //   });
    // });
    // Use custom implementation of `message.compileToV0Message` that allows instruction programIds
    // to also be loaded from `addressLookupTableAccounts`.
    const compiledMessage = (0, compileToWrappedMessageV0_1.compileToWrappedMessageV0)({
        payerKey: message.payerKey,
        recentBlockhash: message.recentBlockhash,
        instructions: message.instructions,
        addressLookupTableAccounts,
    });
    // const compiledMessage = message.compileToV0Message(
    //   addressLookupTableAccounts
    // );
    // We use custom serialization for `transaction_message` that ensures as small byte size as possible.
    const [transactionMessageBytes] = types_1.transactionMessageBeet.serialize({
        numSigners: compiledMessage.header.numRequiredSignatures,
        numWritableSigners: compiledMessage.header.numRequiredSignatures -
            compiledMessage.header.numReadonlySignedAccounts,
        numWritableNonSigners: compiledMessage.staticAccountKeys.length -
            compiledMessage.header.numRequiredSignatures -
            compiledMessage.header.numReadonlyUnsignedAccounts,
        accountKeys: compiledMessage.staticAccountKeys,
        instructions: compiledMessage.compiledInstructions.map((ix) => {
            return {
                programIdIndex: ix.programIdIndex,
                accountIndexes: ix.accountKeyIndexes,
                data: Array.from(ix.data),
            };
        }),
        addressTableLookups: compiledMessage.addressTableLookups,
    });
    return transactionMessageBytes;
}
exports.transactionMessageToMultisigTransactionMessageBytes = transactionMessageToMultisigTransactionMessageBytes;
/** Populate remaining accounts required for execution of the transaction. */
function accountsForTransactionExecute({ connection, transactionPda, vaultPda, message, ephemeralSignerBumps, programId, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const ephemeralSignerPdas = ephemeralSignerBumps.map((_, additionalSignerIndex) => {
            return (0, pda_1.getEphemeralSignerPda)({
                transactionPda,
                ephemeralSignerIndex: additionalSignerIndex,
                programId,
            })[0];
        });
        const addressLookupTableKeys = message.addressTableLookups.map(({ accountKey }) => accountKey);
        const addressLookupTableAccounts = new Map(yield Promise.all(addressLookupTableKeys.map((key) => __awaiter(this, void 0, void 0, function* () {
            const { value } = yield connection.getAddressLookupTable(key);
            if (!value) {
                throw new Error(`Address lookup table account ${key.toBase58()} not found`);
            }
            return [key.toBase58(), value];
        }))));
        // Populate account metas required for execution of the transaction.
        const accountMetas = [];
        // First add the lookup table accounts used by the transaction. They are needed for on-chain validation.
        accountMetas.push(...addressLookupTableKeys.map((key) => {
            return { pubkey: key, isSigner: false, isWritable: false };
        }));
        // Then add static account keys included into the message.
        for (const [accountIndex, accountKey] of message.accountKeys.entries()) {
            accountMetas.push({
                pubkey: accountKey,
                isWritable: isStaticWritableIndex(message, accountIndex),
                // NOTE: vaultPda and ephemeralSignerPdas cannot be marked as signers,
                // because they are PDAs and hence won't have their signatures on the transaction.
                isSigner: isSignerIndex(message, accountIndex) &&
                    !accountKey.equals(vaultPda) &&
                    !ephemeralSignerPdas.find((k) => accountKey.equals(k)),
            });
        }
        // Then add accounts that will be loaded with address lookup tables.
        for (const lookup of message.addressTableLookups) {
            const lookupTableAccount = addressLookupTableAccounts.get(lookup.accountKey.toBase58());
            (0, invariant_1.default)(lookupTableAccount, `Address lookup table account ${lookup.accountKey.toBase58()} not found`);
            for (const accountIndex of lookup.writableIndexes) {
                const pubkey = lookupTableAccount.state.addresses[accountIndex];
                (0, invariant_1.default)(pubkey, `Address lookup table account ${lookup.accountKey.toBase58()} does not contain address at index ${accountIndex}`);
                accountMetas.push({
                    pubkey,
                    isWritable: true,
                    // Accounts in address lookup tables can not be signers.
                    isSigner: false,
                });
            }
            for (const accountIndex of lookup.readonlyIndexes) {
                const pubkey = lookupTableAccount.state.addresses[accountIndex];
                (0, invariant_1.default)(pubkey, `Address lookup table account ${lookup.accountKey.toBase58()} does not contain address at index ${accountIndex}`);
                accountMetas.push({
                    pubkey,
                    isWritable: false,
                    // Accounts in address lookup tables can not be signers.
                    isSigner: false,
                });
            }
        }
        return {
            accountMetas,
            lookupTableAccounts: [...addressLookupTableAccounts.values()],
        };
    });
}
exports.accountsForTransactionExecute = accountsForTransactionExecute;
//# sourceMappingURL=utils.js.map