import { createBatchAddTransactionInstruction, PROGRAM_ID } from "../generated";
import { getBatchTransactionPda, getProposalPda, getTransactionPda, getVaultPda, } from "../pda";
import { transactionMessageToMultisigTransactionMessageBytes } from "../utils";
export function batchAddTransaction({ vaultIndex, multisigPda, member, rentPayer, batchIndex, transactionIndex, ephemeralSigners, transactionMessage, addressLookupTableAccounts, programId = PROGRAM_ID, }) {
    const [proposalPda] = getProposalPda({
        multisigPda,
        transactionIndex: batchIndex,
        programId,
    });
    const [batchPda] = getTransactionPda({
        multisigPda,
        index: batchIndex,
        programId,
    });
    const [batchTransactionPda] = getBatchTransactionPda({
        multisigPda,
        batchIndex,
        transactionIndex,
        programId,
    });
    const [vaultPda] = getVaultPda({
        multisigPda,
        index: vaultIndex,
        programId,
    });
    const transactionMessageBytes = transactionMessageToMultisigTransactionMessageBytes({
        message: transactionMessage,
        addressLookupTableAccounts,
        vaultPda,
    });
    return createBatchAddTransactionInstruction({
        multisig: multisigPda,
        member,
        proposal: proposalPda,
        rentPayer: rentPayer ?? member,
        batch: batchPda,
        transaction: batchTransactionPda,
    }, {
        args: {
            ephemeralSigners,
            transactionMessage: transactionMessageBytes,
        },
    }, programId);
}
//# sourceMappingURL=batchAddTransaction.js.map