import { createVaultTransactionCreateInstruction, PROGRAM_ID, } from "../generated";
import { getTransactionPda, getVaultPda } from "../pda";
import { transactionMessageToMultisigTransactionMessageBytes } from "../utils";
export function vaultTransactionCreate({ multisigPda, transactionIndex, creator, rentPayer, vaultIndex, ephemeralSigners, transactionMessage, addressLookupTableAccounts, memo, programId = PROGRAM_ID, }) {
    const [vaultPda] = getVaultPda({
        multisigPda,
        index: vaultIndex,
        programId,
    });
    const [transactionPda] = getTransactionPda({
        multisigPda,
        index: transactionIndex,
        programId,
    });
    const transactionMessageBytes = transactionMessageToMultisigTransactionMessageBytes({
        message: transactionMessage,
        addressLookupTableAccounts,
        vaultPda,
    });
    return createVaultTransactionCreateInstruction({
        multisig: multisigPda,
        transaction: transactionPda,
        creator,
        rentPayer: rentPayer ?? creator,
    }, {
        args: {
            vaultIndex,
            ephemeralSigners,
            transactionMessage: transactionMessageBytes,
            memo: memo ?? null,
        },
    }, programId);
}
//# sourceMappingURL=vaultTransactionCreate.js.map