import * as transactions from "../transactions/index.js";
import { translateAndThrowAnchorError } from "../errors";
/**
 * Closes Batch and the corresponding Proposal accounts for proposals in terminal states:
 * `Executed`, `Rejected`, or `Cancelled` or stale proposals that aren't Approved.
 *
 * This instruction is only allowed to be executed when all `VaultBatchTransaction` accounts
 * in the `batch` are already closed: `batch.size == 0`.
 */
export async function batchAccountsClose({ connection, feePayer, multisigPda, rentCollector, batchIndex, sendOptions, programId, }) {
    const blockhash = (await connection.getLatestBlockhash()).blockhash;
    const tx = transactions.batchAccountsClose({
        blockhash,
        feePayer: feePayer.publicKey,
        rentCollector,
        batchIndex,
        multisigPda,
        programId,
    });
    tx.sign([feePayer]);
    try {
        return await connection.sendTransaction(tx, sendOptions);
    }
    catch (err) {
        translateAndThrowAnchorError(err);
    }
}
//# sourceMappingURL=batchAccountsClose.js.map