import * as transactions from "../transactions";
import { translateAndThrowAnchorError } from "../errors";
/** Execute a transaction from a batch. */
export async function batchExecuteTransaction({ connection, feePayer, multisigPda, member, batchIndex, transactionIndex, signers, sendOptions, programId, }) {
    const blockhash = (await connection.getLatestBlockhash()).blockhash;
    const tx = await transactions.batchExecuteTransaction({
        connection,
        blockhash,
        feePayer: feePayer.publicKey,
        multisigPda,
        member: member.publicKey,
        batchIndex,
        transactionIndex,
        programId,
    });
    tx.sign([feePayer, member, ...(signers ?? [])]);
    try {
        return await connection.sendTransaction(tx, sendOptions);
    }
    catch (err) {
        translateAndThrowAnchorError(err);
    }
}
//# sourceMappingURL=batchExecuteTransaction.js.map