import * as transactions from "../transactions";
import { translateAndThrowAnchorError } from "../errors";
/** Add a member/key to the multisig and reallocate space if necessary. */
export async function multisigAddMember({ connection, feePayer, multisigPda, configAuthority, rentPayer, newMember, memo, signers, sendOptions, programId, }) {
    const blockhash = (await connection.getLatestBlockhash()).blockhash;
    const tx = transactions.multisigAddMember({
        blockhash,
        feePayer: feePayer.publicKey,
        multisigPda,
        configAuthority,
        rentPayer: rentPayer.publicKey,
        newMember,
        memo,
        programId,
    });
    tx.sign([feePayer, rentPayer, ...(signers ?? [])]);
    try {
        return await connection.sendTransaction(tx, sendOptions);
    }
    catch (err) {
        translateAndThrowAnchorError(err);
    }
}
//# sourceMappingURL=multisigAddMember.js.map