import * as transactions from "../transactions/index";
import { translateAndThrowAnchorError } from "../errors";
/**
 * Create a new spending limit for the controlled multisig.
 */
export async function multisigAddSpendingLimit({ connection, feePayer, multisigPda, configAuthority, spendingLimit, rentPayer, createKey, vaultIndex, mint, amount, period, members, destinations, memo, signers, sendOptions, programId, }) {
    const blockhash = (await connection.getLatestBlockhash()).blockhash;
    const tx = transactions.multisigAddSpendingLimit({
        blockhash,
        feePayer: feePayer.publicKey,
        multisigPda,
        configAuthority,
        spendingLimit,
        rentPayer: rentPayer.publicKey,
        createKey,
        vaultIndex,
        mint,
        amount,
        period,
        members,
        destinations,
        memo,
        programId,
    });
    tx.sign([feePayer, rentPayer, ...(signers ?? [])]);
    try {
        return await connection.sendTransaction(tx, sendOptions);
    }
    catch (err) {
        translateAndThrowAnchorError(err);
    }
}
//# sourceMappingURL=multisigAddSpendingLimit.js.map