import * as transactions from "../transactions/index";
import { translateAndThrowAnchorError } from "../errors";
/**
 * Create a new spending limit for the controlled multisig.
 */
export async function multisigRemoveSpendingLimit({ connection, feePayer, multisigPda, configAuthority, spendingLimit, rentCollector, memo, signers, sendOptions, programId, }) {
    const blockhash = (await connection.getLatestBlockhash()).blockhash;
    const tx = transactions.multisigRemoveSpendingLimit({
        blockhash,
        feePayer: feePayer.publicKey,
        multisigPda,
        configAuthority,
        spendingLimit,
        rentCollector,
        memo,
        programId,
    });
    tx.sign([feePayer, ...(signers ?? [])]);
    try {
        return await connection.sendTransaction(tx, sendOptions);
    }
    catch (err) {
        translateAndThrowAnchorError(err);
    }
}
//# sourceMappingURL=multisigRemoveSpendingLimit.js.map