import * as transactions from "../transactions";
import { translateAndThrowAnchorError } from "../errors";
export async function proposalCreate({ connection, feePayer, creator, rentPayer, multisigPda, transactionIndex, isDraft, sendOptions, programId, }) {
    const blockhash = (await connection.getLatestBlockhash()).blockhash;
    const tx = transactions.proposalCreate({
        blockhash,
        feePayer: feePayer.publicKey,
        multisigPda,
        transactionIndex,
        creator: creator.publicKey,
        isDraft,
        programId,
    });
    const allSigners = [feePayer, creator];
    if (rentPayer) {
        allSigners.push(rentPayer);
    }
    tx.sign(allSigners);
    try {
        return await connection.sendTransaction(tx, sendOptions);
    }
    catch (err) {
        translateAndThrowAnchorError(err);
    }
}
//# sourceMappingURL=proposalCreate.js.map