import * as transactions from "../transactions";
import { translateAndThrowAnchorError } from "../errors";
/** Create a new vault transaction. */
export async function vaultTransactionCreate({ connection, feePayer, multisigPda, transactionIndex, creator, rentPayer, vaultIndex, ephemeralSigners, transactionMessage, addressLookupTableAccounts, memo, signers, sendOptions, programId, }) {
    const blockhash = (await connection.getLatestBlockhash()).blockhash;
    const tx = transactions.vaultTransactionCreate({
        blockhash,
        feePayer: feePayer.publicKey,
        multisigPda,
        transactionIndex,
        creator,
        rentPayer,
        vaultIndex,
        ephemeralSigners,
        transactionMessage,
        addressLookupTableAccounts,
        memo,
        programId,
    });
    tx.sign([feePayer, ...(signers ?? [])]);
    try {
        return await connection.sendTransaction(tx, sendOptions);
    }
    catch (err) {
        translateAndThrowAnchorError(err);
    }
}
//# sourceMappingURL=vaultTransactionCreate.js.map