import * as transactions from "../transactions";
import { translateAndThrowAnchorError } from "../errors";
/**
 *  Execute the multisig transaction.
 *  The transaction must be `ExecuteReady`.
 */
export async function vaultTransactionExecute({ connection, feePayer, multisigPda, transactionIndex, member, signers, sendOptions, programId, }) {
    const blockhash = (await connection.getLatestBlockhash()).blockhash;
    const tx = await transactions.vaultTransactionExecute({
        connection,
        blockhash,
        feePayer: feePayer.publicKey,
        multisigPda,
        transactionIndex,
        member,
        programId,
    });
    tx.sign([feePayer, ...(signers ?? [])]);
    try {
        return await connection.sendTransaction(tx, sendOptions);
    }
    catch (err) {
        translateAndThrowAnchorError(err);
    }
}
//# sourceMappingURL=vaultTransactionExecute.js.map