import { TransactionMessage, VersionedTransaction, } from "@solana/web3.js";
import * as instructions from "../instructions/index.js";
/**
 * Closes Batch and the corresponding Proposal accounts for proposals in terminal states:
 * `Executed`, `Rejected`, or `Cancelled` or stale proposals that aren't Approved.
 *
 * This instruction is only allowed to be executed when all `VaultBatchTransaction` accounts
 * in the `batch` are already closed: `batch.size == 0`.
 */
export function batchAccountsClose({ blockhash, feePayer, multisigPda, rentCollector, batchIndex, programId, }) {
    const message = new TransactionMessage({
        payerKey: feePayer,
        recentBlockhash: blockhash,
        instructions: [
            instructions.batchAccountsClose({
                multisigPda,
                rentCollector,
                batchIndex,
                programId,
            }),
        ],
    }).compileToV0Message();
    return new VersionedTransaction(message);
}
//# sourceMappingURL=batchAccountsClose.js.map