import { TransactionMessage, VersionedTransaction, } from "@solana/web3.js";
import * as instructions from "../instructions";
/**
 * Returns unsigned `VersionedTransaction` that needs to be
 * signed by `creator` and `feePayer` before sending it.
 */
export function batchCreate({ blockhash, feePayer, multisigPda, batchIndex, creator, rentPayer, vaultIndex, memo, programId, }) {
    const message = new TransactionMessage({
        payerKey: feePayer,
        recentBlockhash: blockhash,
        instructions: [
            instructions.batchCreate({
                multisigPda,
                creator,
                rentPayer: rentPayer ?? creator,
                batchIndex,
                vaultIndex,
                memo,
                programId,
            }),
        ],
    }).compileToV0Message();
    return new VersionedTransaction(message);
}
//# sourceMappingURL=batchCreate.js.map