import { TransactionMessage, VersionedTransaction, } from "@solana/web3.js";
import * as instructions from "../instructions/index";
/**
 * Returns unsigned `VersionedTransaction` that needs to be
 * signed by `configAuthority`, `rent_payer` and `feePayer` before sending it.
 */
export function multisigAddSpendingLimit({ blockhash, feePayer, multisigPda, configAuthority, spendingLimit, rentPayer, createKey, vaultIndex, mint, amount, period, members, destinations, memo, programId, }) {
    const message = new TransactionMessage({
        payerKey: feePayer,
        recentBlockhash: blockhash,
        instructions: [
            instructions.multisigAddSpendingLimit({
                configAuthority,
                multisigPda,
                spendingLimit,
                rentPayer,
                createKey,
                vaultIndex,
                mint,
                amount,
                period,
                members,
                destinations,
                memo,
                programId,
            }),
        ],
    }).compileToV0Message();
    return new VersionedTransaction(message);
}
//# sourceMappingURL=multisigAddSpendingLimit.js.map