import { TransactionMessage, VersionedTransaction, } from "@solana/web3.js";
import * as instructions from "../instructions/index";
/**
 * Returns unsigned `VersionedTransaction` that needs to be
 * signed by `configAuthority` and `feePayer` before sending it.
 */
export function multisigRemoveSpendingLimit({ blockhash, feePayer, multisigPda, configAuthority, spendingLimit, rentCollector, memo, programId, }) {
    const message = new TransactionMessage({
        payerKey: feePayer,
        recentBlockhash: blockhash,
        instructions: [
            instructions.multisigRemoveSpendingLimit({
                configAuthority,
                multisigPda,
                spendingLimit,
                rentCollector,
                memo,
                programId,
            }),
        ],
    }).compileToV0Message();
    return new VersionedTransaction(message);
}
//# sourceMappingURL=multisigRemoveSpendingLimit.js.map