import { TransactionMessage, VersionedTransaction, } from "@solana/web3.js";
import * as instructions from "../instructions/index.js";
/**
 * Closes a VaultBatchTransaction belonging to the Batch and Proposal defined by `batchIndex`.
 * VaultBatchTransaction can be closed if either:
 * - it's marked as executed within the batch;
 * - the proposal is in a terminal state: `Executed`, `Rejected`, or `Cancelled`.
 * - the proposal is stale and not `Approved`.
 */
export function vaultBatchTransactionAccountClose({ blockhash, feePayer, multisigPda, rentCollector, batchIndex, transactionIndex, programId, }) {
    const message = new TransactionMessage({
        payerKey: feePayer,
        recentBlockhash: blockhash,
        instructions: [
            instructions.vaultBatchTransactionAccountClose({
                multisigPda,
                rentCollector,
                batchIndex,
                transactionIndex,
                programId,
            }),
        ],
    }).compileToV0Message();
    return new VersionedTransaction(message);
}
//# sourceMappingURL=vaultBatchTransactionAccountClose.js.map