import { TransactionMessage, VersionedTransaction, } from "@solana/web3.js";
import * as instructions from "../instructions";
/**
 * Returns unsigned `VersionedTransaction` that needs to be
 * signed by `member` and `feePayer` before sending it.
 */
export async function vaultTransactionExecute({ connection, blockhash, feePayer, multisigPda, transactionIndex, member, programId, }) {
    const { instruction, lookupTableAccounts } = await instructions.vaultTransactionExecute({
        connection,
        multisigPda,
        member,
        transactionIndex,
        programId,
    });
    const message = new TransactionMessage({
        payerKey: feePayer,
        recentBlockhash: blockhash,
        instructions: [instruction],
    }).compileToV0Message(lookupTableAccounts);
    return new VersionedTransaction(message);
}
//# sourceMappingURL=vaultTransactionExecute.js.map